/*!
 *  \file    main_images_large.c
 *  \author  Wim Dolman (<a href="mailto:w.e.dolman@hva.nl">w.e.dolman@hva.nl</a>)
 *  \date    30-05-2020
 *  \version 3.0
 *
 *  \brief   Example: show four 60K pictures (128x160 pixels) on the display
 *           The original png-pictures are converted to c with a dedicated
 *           program png2c_ucg
 */

#define  F_CPU   32000000UL   //!< System clock is 32 MHz

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include <stdlib.h>

#include "../clock.h"
#include "../ucglib_xmega.h"

#include "leeuwinnen_large/beerensteyn_lineth.h"
#include "leeuwinnen_large/donk_danielle_van_de.h"
#include "leeuwinnen_large/gragt_stephanie_van_der.h"
#include "leeuwinnen_large/groenen_jackie.h"

/*!
 *  \brief connectArraySPI contains the non-SPI connections with display
 */
pin_t connectArraySPI[] = {   
  { UCG_XMEGA_PIN_RST, &PORTD, PIN3_bp },   //!< RST pin is D3
  { UCG_XMEGA_PIN_CD,  &PORTD, PIN2_bp },   //!< CD (A0) pin is D2
  { UCG_XMEGA_PIN_NULL }  
};             

ucg_t  ucg;      //!< ucg is a necessary global structure for ucg_lib

/*!
 *  \brief Main function to demonstrate the usage of ucglib_xmega library
 */
int main(void)
{
  init_clock();
             
  ucg_connectXmega(&SPID, connectArraySPI, 0);
  ucg_Init(&ucg, ucg_dev_st7735_18x128x160, ucg_ext_st7735_18,
           (int (*)(struct _ucg_t *, int,  unsigned int,  unsigned char *)) ucg_comm_xmega);
  ucg_ClearScreen(&ucg);

  ucg_SetColor(&ucg, 0, 255, 255, 255);
  ucg_SetFontMode(&ucg, UCG_FONT_MODE_SOLID);
  ucg_SetFont(&ucg, ucg_font_8x13_mr);
  
  while (1) {
    ucg_image_beerensteyn_lineth(&ucg, 0, 0);
    ucg_DrawString(&ucg, 0, 145, 0, "Beerensteyn");
    _delay_ms(500);

    ucg_image_donk_danielle_van_de(&ucg, 0, 0);
    ucg_DrawString(&ucg, 0, 145, 0, "van de Donk");
    _delay_ms(500);

   ucg_image_gragt_stephanie_van_der(&ucg, 0, 0);
   ucg_DrawString(&ucg, 0, 145, 0, "van der Gragt");
   _delay_ms(500);

   ucg_image_groenen_jackie(&ucg, 0, 0);
   ucg_DrawString(&ucg, 0, 145, 0, "Groenen");
   _delay_ms(500);
  }
}

